<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
 
function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	
	// Color schemes
	$color_scheme = array("red" => __('Red', 'twentyfourteen'), "green" => __('Green', 'twentyfourteen'), "blue" => __('Blue', 'twentyfourteen'), "sandy" =>__('Sandy', 'twentyfourteen'), "yellow" =>__('Yellow', 'twentyfourteen'),  "cherry" =>__('Cherry', 'twentyfourteen'),  "orange" =>__('Orange', 'twentyfourteen'));

	$radio = array("0" => __('No', 'twentyfourteen'),"1" => __('Yes', 'twentyfourteen'));

	// Pull all the categories into an array
	$options_categories = array();  
    $args = array();
	$options_categories_obj = get_categories( );

	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_stylesheet_directory_uri() . '/images/';
		
	$options = array();
		
	$options[] = array( "name" => __('HomePage Settings', 'twentyfourteen'),
						"type" => "heading");					

	$options[] = array( "name" => __('Add Logo', 'twentyfourteen'),
						"desc" => __('You can upload logo image for your website (optional).', 'twentyfourteen'),
						"id" => "logo_image",
						"type" => "upload");
									
					   
    return $options;
}